## Sid Meier's Civilization 4
## Copyright Firaxis Games 2005

from CvPythonExtensions import *
import CvUtil
import PyHelpers
import CvEventManager
import RandomNameUtils	
import CvConfigParser

gc = CyGlobalContext()

PyPlayer = PyHelpers.PyPlayer

# Change this value to false if unnamed great persons should not be renamed.
# Default value is true
g_bRenameUnnamedGreatPersons = true

# Change this value to false if great persons should not be named appropriately
# with their owner's civilization
# Default value is true
g_bCivilizationAppropriateGreatPersonNames = true

# globals
###################################################
class CvNoNameGreatPersonRenamerModEventManager:

	def __init__(self, eventManager):
		# initialize base class

		eventManager.addEventHandler("greatPersonBorn", self.onGreatPersonBorn)
		# eventManager.addEventHandler("mouseEvent", self.onMouseEvent)
		
		global g_bRenameUnnamedGreatPersons
		global g_bCivilizationAppropriateGreatPersonNames
		
		config = CvConfigParser.CvConfigParser("No Name Great Person Renamer Mod Config.ini")

		if(config != None):

			g_bRenameUnnamedGreatPersons = config.getboolean("No Name Great Person Renamer Mod", "Rename Unnamed Great Persons", True)

			g_bCivilizationAppropriateGreatPersonNames = config.getboolean("No Name Great Person Renamer Mod", "Civilization Appropriate Great Person Names", True)

	"""
	# Test code to make sure that we can go through the vanilla great person
	# names and test the random names
	def onMouseEvent(self, argsList):
	
		gc.getPlayer(0).getCapitalCity().createGreatPeople(gc.getInfoTypeForString("UNIT_ARTIST"), true)
	"""
		
	def onGreatPersonBorn(self, argsList):
		'Great Person Born'
		pUnit, iPlayer, pCity = argsList
		player = PyPlayer(iPlayer)
		
		# Check if we should even show the popup:
		if pUnit.isNone() or pCity.isNone():
			return
		
		if(len(pUnit.getNameNoDesc()) == 0):
			if(not g_bRenameUnnamedGreatPersons):
				return
				
			iCivilizationType = player.player.getCivilizationType()
			
			if(not g_bCivilizationAppropriateGreatPersonNames):
				iCivilizationType = gc.getGame().getMapRand().get(gc.getNumCivilizationInfos(),"NOGPRM")
				
			pUnit.setName(RandomNameUtils.getRandomCivilizationName(iCivilizationType))
			

